@@ -12,7 +12,7 @@ set.edge.attribute(test,'weight',10:11)
 
 expect_equal(as.matrix.network.edgelist(test),structure(c(5L, 1L, 1L, 5L), .Dim = c(2L, 2L), n = 5, vnames = 1:5))
 # sort order should be different
-expect_equal(as.edgelist(test),structure(c(1L, 5L, 5L, 1L), .Dim = c(2L, 2L), n = 5, vnames = 1:5, directed = TRUE, bipartite = FALSE, loops = FALSE, inverted = FALSE, class = c("edgelist","matrix")))
+expect_equal(as.edgelist(test),structure(c(1L, 5L, 5L, 1L), .Dim = c(2L, 2L), n = 5, vnames = 1:5, directed = TRUE, bipartite = FALSE, loops = FALSE, class = c("edgelist","matrix")))
 
 expect_true(is.edgelist(as.edgelist(test)))
 
@@ -22,6 +22,14 @@ expect_equal(as.matrix.network.edgelist(test,attrname='weight'),structure(c(5L,
 # character attribute  NOTE makes the matrix character as well
 expect_equal(as.matrix.network.edgelist(test,attrname='value'),structure(c('5', '1', '1', '5', 'a', 'b'), .Dim = 2:3, n = 5, vnames = 1:5))
 
+# character attribute with tibble output: does not make matrix character
+expect_equal(as.edgelist(test,attrname='value', output="tibble"),
+             structure(list(.tail = c(1L, 5L), .head = c(5L, 1L), .eid = 2:1, 
+                            value = c("b", "a")), row.names = c(NA, -2L),
+                       class = c("edgelist", "tbl_df", "tbl", "data.frame"),
+                       n = 5, vnames = 1:5, directed = TRUE, bipartite = FALSE, loops = FALSE)
+)
+
 
 undir<-network.initialize(5,directed=FALSE)
 add.edges(undir,5,1)
@@ -35,4 +43,4 @@ as.edgelist(network.initialize(0))
 deledge<-network.initialize(5)
 add.edges(deledge,1:3,2:4)
 delete.edges(deledge,2)
-expect_equal(as.edgelist(deledge),structure(c(1L, 3L, 2L, 4L), .Dim = c(2L, 2L), n = 5, vnames = 1:5, directed = TRUE, bipartite = FALSE, loops = FALSE, inverted = FALSE, class = c("edgelist", "matrix")))
+expect_equal(as.edgelist(deledge),structure(c(1L, 3L, 2L, 4L), .Dim = c(2L, 2L), n = 5, vnames = 1:5, directed = TRUE, bipartite = FALSE, loops = FALSE, class = c("edgelist", "matrix")))
